% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gen-random-normal-walk-drift.R
\name{random_normal_drift_walk}
\alias{random_normal_drift_walk}
\title{Generate Multiple Random Walks with Drift}
\usage{
random_normal_drift_walk(
  .num_walks = 25,
  .n = 100,
  .mu = 0,
  .sd = 1,
  .drift = 0.1,
  .initial_value = 0
)
}
\arguments{
\item{.num_walks}{Integer. The number of random walks to generate. Default is 25.}

\item{.n}{Integer. The number of steps in each random walk. Default is 100.}

\item{.mu}{Numeric. The mean of the normal distribution used for generating steps. Default is 0.}

\item{.sd}{Numeric. The standard deviation of the normal distribution used for generating steps. Default is 1.}

\item{.drift}{Numeric. The drift term to be added to each step. Default is 0.1.}

\item{.initial_value}{A numeric value indicating the initial value of the walks. Default is 0.}
}
\value{
A tibble in long format with columns \code{walk_number}, \code{x} (step index),
and \code{y} (walk value). The tibble has attributes for the number of walks,
number of steps, mean, standard deviation, and drift.
}
\description{
This function generates a specified number of random walks, each consisting
of a specified number of steps. The steps are generated from a normal
distribution with a given mean and standard deviation. An additional drift
term is added to each step to introduce a consistent directional component
to the walks.
}
\details{
This function generates multiple random walks with a specified drift.
Each walk is generated using a normal distribution for the steps, with an
additional drift term added to each step.
}
\examples{
library(ggplot2)

set.seed(123)
walks <- random_normal_drift_walk(.num_walks = 10, .n = 50, .mu = 0, .sd = 1.2,
                                  .drift = 0.05)
ggplot(walks, aes(x = x, y = y, group = walk_number, color = walk_number)) +
  geom_line() +
  labs(title = "Random Walks with Drift", x = "Time", y = "Value") +
  theme_minimal() +
  theme(legend.position = "none")

}
\seealso{
Other Generator Functions: 
\code{\link{brownian_motion}()},
\code{\link{discrete_walk}()},
\code{\link{geometric_brownian_motion}()},
\code{\link{random_normal_walk}()}
}
\author{
Steven P. Sanderson II, MPH
}
\concept{Generator Functions}
